summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorYorhel <git@yorhel.nl>2021-06-10 09:33:32 +0200
committerYorhel <git@yorhel.nl>2021-06-10 09:33:32 +0200
commitd0896806c17200d6493e3d6f7d65e0fa6ff7752e (patch)
treea181dee684f46e674fda7a4dc35684c9c734805b
parenta96aeb6310f48ec616154c1be7e40ccbfbd0a3a2 (diff)
Add Debian testing + prefer that instead of Ubuntu
-rw-r--r--sql/schema.sql11
-rwxr-xr-xutil/debian.sh5
-rwxr-xr-xwww/index.pl8
3 files changed, 15 insertions, 9 deletions
diff --git a/sql/schema.sql b/sql/schema.sql
index 37d5cab..9b1e974 100644
--- a/sql/schema.sql
+++ b/sql/schema.sql
@@ -134,7 +134,7 @@ INSERT INTO systems (id, name, release, short, relorder) VALUES
(80, 'FreeBSD', '9.0', 'freebsd-9.0', 52),
(81, 'Ubuntu', '12.10', 'ubuntu-quantal', 16),
(82, 'Ubuntu', '13.04', 'ubuntu-raring', 17),
- (83, 'Debian', '7.0', 'debian-wheezy', 11),
+ (83, 'Debian', '7', 'debian-wheezy', 11),
(84, 'FreeBSD', '8.4', 'freebsd-8.4', 51),
(85, 'FreeBSD', '9.1', 'freebsd-9.1', 53),
(86, 'FreeBSD', '9.2', 'freebsd-9.2', 54),
@@ -142,7 +142,7 @@ INSERT INTO systems (id, name, release, short, relorder) VALUES
(88, 'Ubuntu', '14.04', 'ubuntu-trusty', 19),
(89, 'Ubuntu', '14.10', 'ubuntu-utopic', 20),
(90, 'Ubuntu', '15.04', 'ubuntu-vivid', 21),
- (91, 'Debian', '8.0', 'debian-jessie', 12),
+ (91, 'Debian', '8', 'debian-jessie', 12),
(92, 'Ubuntu', '15.10', 'ubuntu-wily', 22),
(93, 'Ubuntu', '16.04', 'ubuntu-xenial', 23),
(94, 'FreeBSD', '9.3', 'freebsd-9.3', 55),
@@ -178,7 +178,7 @@ INSERT INTO systems (id, name, release, short, relorder) VALUES
(124,'Fedora', '24', 'fedora-24', 23),
(125,'Fedora', '25', 'fedora-25', 24),
(126,'Ubuntu', '17.04', 'ubuntu-zesty', 25),
- (127,'Debian', '9.0', 'debian-stretch', 13),
+ (127,'Debian', '9', 'debian-stretch', 13),
(128,'Fedora', '26', 'fedora-26', 25),
(129,'FreeBSD', '11.1', 'freebsd-11.1', 62),
(130,'Ubuntu', '17.10', 'ubuntu-artful', 26),
@@ -240,7 +240,7 @@ INSERT INTO systems (id, name, release, short, relorder) VALUES
(187,'CentOS', '7.6', 'centos-7.6', 50),
(188,'FreeBSD', '12.0', 'freebsd-12.0', 70),
(189,'Ubuntu', '19.04', 'ubuntu-disco', 29),
- (190,'Debian', '10.0', 'debian-buster', 14),
+ (190,'Debian', '10 (stable)', 'debian-buster', 14),
(191,'Fedora', '30', 'fedora-30', 29),
(192,'FreeBSD', '11.3', 'freebsd-11.3', 64),
(193,'Ubuntu', '19.10', 'ubuntu-eoan', 30),
@@ -261,7 +261,8 @@ INSERT INTO systems (id, name, release, short, relorder) VALUES
(208,'FreeBSD', '12.2', 'freebsd-12.2', 72),
(209,'FreeBSD', '13.0', 'freebsd-13.0', 80),
(210,'Ubuntu', '21.04', 'ubuntu-hirsute', 33),
- (211,'Fedora', '34', 'fedora-34', 33);
+ (211,'Fedora', '34', 'fedora-34', 33),
+ (212,'Debian', 'testing','debian-bullseye',15);
-- Removes any path components and compression extensions from the filename.
diff --git a/util/debian.sh b/util/debian.sh
index 52c9dd5..2a9fafc 100755
--- a/util/debian.sh
+++ b/util/debian.sh
@@ -63,6 +63,10 @@ case "$1" in
index_deb debian-buster $CMIRROR buster "main contrib non-free" cmp amd64
index_deb debian-buster $CMIRROR buster-updates "main contrib non-free" cmp amd64
;;
+ bullseye)
+ index_deb debian-bullseye $CMIRROR bullseye "main contrib non-free" cmp amd64
+ #index_deb debian-bullseye $CMIRROR bullseye-updates "main contrib non-free" cmp amd64
+ ;;
old)
$0 buzz
$0 rex
@@ -81,6 +85,7 @@ case "$1" in
current)
$0 stretch
$0 buster
+ $0 bullseye
;;
all)
$0 old
diff --git a/www/index.pl b/www/index.pl
index b0a9235..6bd5df9 100755
--- a/www/index.pl
+++ b/www/index.pl
@@ -134,7 +134,7 @@ sub man_pref {
# 3. stdloc: Prefer man pages in standard locations
# 4. secmatch: Prefer an exact section match
# 5. arch: Prefer Arch over other systems (because it tends to be the most up-to-date, and closest to upstreams)
# 6. ubuntu: If there's no Arch, prefer Ubuntu over other systems (again, tends to be more up-to-date)
# (also resolves distro-specific tooling disputes such as https://code.blicky.net/yorhel/manned/issues/1 )
# 7. sysrel: Prefer a later system release over an older release
# 8. secorder: Lower sections before higher sections (because man does it this way, for some reason)
@@ -159,10 +159,10 @@ sub man_pref {
SELECT * FROM f_stdloc WHERE NOT EXISTS(SELECT 1 FROM f_stdloc WHERE (man).section =}, \$section, q{) OR (man).section =}, \$section, q{
), f_arch AS(
SELECT * FROM f_secmatch WHERE NOT EXISTS(SELECT 1 FROM}, length $section ? 'f_secmatch' : 'f_stdloc', q{WHERE (sys).id = 1) OR (sys).id = 1
- ), f_ubuntu AS(
- SELECT * FROM f_arch WHERE NOT EXISTS(SELECT 1 FROM f_arch WHERE (sys).name = 'Ubuntu') OR (sys).name = 'Ubuntu'
+ ), f_debian AS(
+ SELECT * FROM f_arch WHERE NOT EXISTS(SELECT 1 FROM f_arch WHERE (sys).name = 'Debian') OR (sys).name = 'Debian'
), f_sysrel AS(
- SELECT * FROM f_ubuntu a WHERE NOT EXISTS(SELECT 1 FROM f_ubuntu b WHERE (a.sys).name = (b.sys).name AND (a.sys).relorder < (b.sys).relorder)
+ SELECT * FROM f_debian a WHERE NOT EXISTS(SELECT 1 FROM f_debian b WHERE (a.sys).name = (b.sys).name AND (a.sys).relorder < (b.sys).relorder)
), f_secorder AS(
SELECT * FROM f_sysrel a WHERE NOT EXISTS(SELECT 1 FROM f_sysrel b WHERE (a.man).section > (b.man).section)
), f_pkgdate AS(
@@ -134,7 +134,7 @@ sub man_pref {
# 4. secmatch: Prefer an exact section match
# 5. arch: Prefer Arch over other systems (because it tends to be the most up-to-date, and closest to upstreams)
- # 6. ubuntu: If there's no Arch, prefer Ubuntu over other systems (again, tends to be more up-to-date)
+ # 6. debian: If there's no Arch, prefer Debian over other systems (again, tends to be more up-to-date)
# (also resolves distro-specific tooling disputes such as https://code.blicky.net/yorhel/manned/issues/1 )
# 7. sysrel: Prefer a later system release over an older release